==> blender_2.70a.orig.tar.xz: blender-v2.70a/source/blender/freestyle/intern/python/Iterator/BPy_orientedViewEdgeIterator.h <==
/*
 * ***** BEGIN GPL LICENSE BLOCK *****
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * ***** END GPL LICENSE BLOCK *****
 */

/** \file source/blender/freestyle/intern/python/Iterator/BPy_orientedViewEdgeIterator.h
 *  \ingroup freestyle
 */

#ifndef __FREESTYLE_PYTHON_ORIENTEDVIEWEDGEITERATOR_H__
#define __FREESTYLE_PYTHON_ORIENTEDVIEWEDGEITERATOR_H__

#include "../../stroke/Stroke.h"
#include "../../view_map/ViewMapIterators.h"

#include "../BPy_Iterator.h"

#ifdef __cplusplus
extern "C" {
#endif

///////////////////////////////////////////////////////////////////////////////////////////

#include <Python.h>

extern PyTypeObject orientedViewEdgeIterator_Type;

#define BPy_orientedViewEdgeIterator_Check(v) \
            (PyObject_IsInstance((PyObject *)v, (PyObject *)&orientedViewEdgeIterator_Type))

/*---------------------------Python BPy_orientedViewEdgeIterator structure definition----------*/
typedef struct {
	BPy_Iterator py_it;
	ViewVertexInternal::orientedViewEdgeIterator *ove_it;
	bool reversed;
	bool at_start;
} BPy_orientedViewEdgeIterator;

///////////////////////////////////////////////////////////////////////////////////////////

#ifdef __cplusplus
}
#endif

#endif /* __FREESTYLE_PYTHON_ORIENTEDVIEWEDGEITERATOR_H__ */

==> blender-3.0.0.tar.xz: blender-3.0.0/source/blender/freestyle/intern/python/Iterator/BPy_orientedViewEdgeIterator.h <==
/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

/** \file
 * \ingroup freestyle
 */

#pragma once

#include "../BPy_Iterator.h"

#include "../../view_map/ViewMapIterators.h"

#ifdef __cplusplus
extern "C" {
#endif

///////////////////////////////////////////////////////////////////////////////////////////

extern PyTypeObject orientedViewEdgeIterator_Type;

#define BPy_orientedViewEdgeIterator_Check(v) \
  (PyObject_IsInstance((PyObject *)v, (PyObject *)&orientedViewEdgeIterator_Type))

/*---------------------------Python BPy_orientedViewEdgeIterator structure definition----------*/
typedef struct {
  BPy_Iterator py_it;
  Freestyle::ViewVertexInternal::orientedViewEdgeIterator *ove_it;
  bool reversed;
  bool at_start;
} BPy_orientedViewEdgeIterator;

///////////////////////////////////////////////////////////////////////////////////////////

#ifdef __cplusplus
}
#endif
